Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormatt <matt@59fd770c-687e-43c8-a1e3-f5a4ff64c105>2008-12-08 18:30:03 +0300
committermatt <matt@59fd770c-687e-43c8-a1e3-f5a4ff64c105>2008-12-08 18:30:03 +0300
commit663a05bcc2c9dec65b55f66d8428b925421b286f (patch)
tree482a13df67ecf66d41ff92adeb403822d7b2b2f6 /core/ViewDataTable.php
parenta7593bab4999ca4e2817056080a6001b70b20eda (diff)
- refactoring API/*
Diffstat (limited to 'core/ViewDataTable.php')
-rw-r--r--core/ViewDataTable.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/core/ViewDataTable.php b/core/ViewDataTable.php
index 224e627e60..164e5066dc 100644
--- a/core/ViewDataTable.php
+++ b/core/ViewDataTable.php
@@ -10,6 +10,7 @@
*/
require_once "API/Request.php";
+require_once "API/FilterDataTable.php";
/**
* This class is used to load (from the API) and customize the output of a given DataTable.
@@ -36,7 +37,6 @@ require_once "API/Request.php";
* @package Piwik_ViewDataTable
*
*/
-
abstract class Piwik_ViewDataTable
{
/**
@@ -422,7 +422,7 @@ abstract class Piwik_ViewDataTable
* - etc.
*
* The values are loaded:
* - from the generic filters that are applied by default @see Piwik_API_ResponseBuilder::getGenericFiltersInformation()
* - from the values already available in the GET array
* - from the values set using methods from this class (eg. setSearchPattern(), setLimit(), etc.)
*
@@ -433,7 +433,7 @@ abstract class Piwik_ViewDataTable
// build javascript variables to set
$javascriptVariablesToSet = array();
- $genericFilters = Piwik_API_ResponseBuilder::getGenericFiltersInformation();
+ $genericFilters = Piwik_API_DataTableGenericFilter::getGenericFiltersInformation();
foreach($genericFilters as $filter)
{
foreach($filter as $filterVariableName => $filterInfo)
@@ -422,7 +422,7 @@ abstract class Piwik_ViewDataTable
*
* The values are loaded:
- * - from the generic filters that are applied by default @see Piwik_API_ResponseBuilder::getGenericFiltersInformation()
+ * - from the generic filters that are applied by default @see Piwik_API_DataTableGenericFilter.php::getGenericFiltersInformation()
* - from the values already available in the GET array
* - from the values set using methods from this class (eg. setSearchPattern(), setLimit(), etc.)